@@ -12,13 +12,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from collections.abc import Mapping
+from collections import abc
 from datetime import datetime
+from datetime import timezone
 from contextlib import contextmanager
 from importlib import import_module
 from itertools import count
 from logging import getLogger
-from typing import Dict
 from importlib_metadata import entry_points
 
 import getpass
@@ -26,6 +26,7 @@ import os
 import pickle
 import socket
 import time
+import typing as t
 import uuid
 
 from yoyo import exceptions
@@ -83,7 +84,6 @@ class TransactionManager:
 
 
 class SavepointTransactionManager(TransactionManager):
-
     id = None
     id_generator = count(1)
 
@@ -106,7 +106,6 @@ class SavepointTransactionManager(TransactionManager):
 
 
 class DatabaseBackend:
-
     driver_module = ""
 
     log_table = "_yoyo_log"
@@ -116,42 +115,47 @@ class DatabaseBackend:
     migration_table = "_yoyo_migrations"
     is_applied_sql = """
         SELECT COUNT(1) FROM {0.migration_table_quoted}
-        WHERE id=:id"""
+        WHERE {quoted.id}=:id}"""
     mark_migration_sql = (
         "INSERT INTO {0.migration_table_quoted} "
-        "(migration_hash, migration_id, applied_at_utc) "
+        "({quoted.migration_hash}, {quoted.migration_id}, {quoted.applied_at_utc}) "
         "VALUES (:migration_hash, :migration_id, :when)"
     )
+
     unmark_migration_sql = (
         "DELETE FROM {0.migration_table_quoted} WHERE "
-        "migration_hash = :migration_hash"
+        "{quoted.migration_hash} = :migration_hash"
     )
+
     applied_migrations_sql = (
-        "SELECT migration_hash FROM "
+        "SELECT {quoted.migration_hash} FROM "
         "{0.migration_table_quoted} "
-        "ORDER by applied_at_utc"
+        "ORDER by {quoted.applied_at_utc}"
+    )
+    create_test_table_sql = (
+        "CREATE TABLE {table_name_quoted} ({quoted.id} INT PRIMARY KEY)"
     )
-    create_test_table_sql = "CREATE TABLE {table_name_quoted} " "(id INT PRIMARY KEY)"
     log_migration_sql = (
         "INSERT INTO {0.log_table_quoted} "
-        "(id, migration_hash, migration_id, operation, "
-        "username, hostname, created_at_utc) "
+        "({quoted.id}, {quoted.migration_hash}, {quoted.migration_id}, "
+        "{quoted.operation}, {quoted.username}, {quoted.hostname}, "
+        "{quoted.created_at_utc}) "
         "VALUES (:id, :migration_hash, :migration_id, "
         ":operation, :username, :hostname, :created_at_utc)"
     )
     create_lock_table_sql = (
         "CREATE TABLE {0.lock_table_quoted} ("
-        "locked INT DEFAULT 1, "
-        "ctime TIMESTAMP,"
-        "pid INT NOT NULL,"
-        "PRIMARY KEY (locked))"
+        "{quoted.locked} INT DEFAULT 1, "
+        "{quoted.ctime} TIMESTAMP,"
+        "{quoted.pid} INT NOT NULL,"
+        "PRIMARY KEY ({quoted.locked}))"
     )
 
     _driver = None
     _is_locked = False
     _in_transaction = False
     _internal_schema_updated = False
-    _transactional_ddl_cache: Dict[bytes, bool] = {}
+    _transactional_ddl_cache: dict[bytes, bool] = {}
 
     def __init__(self, dburi, migration_table):
         self.uri = dburi
@@ -178,6 +182,19 @@ class DatabaseBackend:
         exceptions.register(driver.DatabaseError)
         return driver
 
+    def format_sql(self, s, **kwargs):
+        """
+        Take a string in the format used by the various ``..._sql`` class
+        variables and format it.
+        """
+        quote_identifier = self.quote_identifier
+
+        class Quoter:
+            def __getattr__(self, s):
+                return quote_identifier(s)
+
+        return s.format(self, quoted=Quoter(), **kwargs)
+
     @property
     def driver(self):
         if self._driver:
@@ -229,7 +246,9 @@ class DatabaseBackend:
         """
         table_name = "yoyo_tmp_{}".format(utils.get_random_string(10))
         table_name_quoted = self.quote_identifier(table_name)
-        sql = self.create_test_table_sql.format(table_name_quoted=table_name_quoted)
+        sql = self.format_sql(
+            self.create_test_table_sql, table_name_quoted=table_name_quoted
+        )
         try:
             with self.transaction(rollback_on_exit=True):
                 self.execute(sql)
@@ -238,12 +257,12 @@ class DatabaseBackend:
 
         try:
             with self.transaction():
-                self.execute("DROP TABLE {}".format(table_name_quoted))
+                self.execute(f"DROP TABLE {table_name_quoted}")
         except self.DatabaseError:
             return True
         return False
 
-    def list_tables(self, **kwargs):
+    def list_tables(self, **kwargs) -> list[str]:
         """
         Return a list of tables present in the backend.
         This is used by the test suite to clean up tables
@@ -286,19 +305,19 @@ class DatabaseBackend:
         """
         Create a new savepoint with the given id
         """
-        self.execute("SAVEPOINT {}".format(id))
+        self.execute(f"SAVEPOINT {self.quote_identifier(id)}")
 
     def savepoint_release(self, id):
         """
         Release (commit) the savepoint with the given id
         """
-        self.execute("RELEASE SAVEPOINT {}".format(id))
+        self.execute(f"RELEASE SAVEPOINT {self.quote_identifier(id)}")
 
     def savepoint_rollback(self, id):
         """
         Rollback the savepoint with the given id
         """
-        self.execute("ROLLBACK TO SAVEPOINT {}".format(id))
+        self.execute(f"ROLLBACK TO SAVEPOINT {self.quote_identifier(id)}")
 
     @contextmanager
     def disable_transactions(self):
@@ -332,29 +351,35 @@ class DatabaseBackend:
     def _insert_lock_row(self, pid, timeout, poll_interval=0.5):
         poll_interval = min(poll_interval, timeout)
         started = time.time()
+        qi = self.quote_identifier
         while True:
             try:
                 with self.transaction():
                     self.execute(
-                        "INSERT INTO {} (locked, ctime, pid) "
-                        "VALUES (1, :when, :pid)".format(self.lock_table_quoted),
-                        {"when": datetime.utcnow(), "pid": pid},
+                        f"""
+                        INSERT INTO {self.lock_table_quoted}
+                        ({qi('locked')}, {qi('ctime')}, {qi('pid')})
+                        VALUES (1, :when, :pid)
+                        """,
+                        {
+                            "when": datetime.now(timezone.utc).replace(tzinfo=None),
+                            "pid": pid,
+                        },
                     )
             except self.DatabaseError:
                 if timeout and time.time() > started + timeout:
                     cursor = self.execute(
-                        "SELECT pid FROM {}".format(self.lock_table_quoted)
+                        f"SELECT {qi('pid')} FROM {self.lock_table_quoted}"
                     )
                     row = cursor.fetchone()
                     if row:
                         raise exceptions.LockTimeout(
-                            "Process {} has locked this database "
-                            "(run yoyo break-lock to remove this lock)".format(row[0])
+                            f"Process {row[0]} has locked this database "
+                            "(run yoyo break-lock to remove this lock)"
                         )
                     else:
                         raise exceptions.LockTimeout(
-                            "Database locked "
-                            "(run yoyo break-lock to remove this lock)"
+                            "Database locked (run yoyo break-lock to remove this lock)"
                         )
                 time.sleep(poll_interval)
             else:
@@ -362,16 +387,17 @@ class DatabaseBackend:
 
     def _delete_lock_row(self, pid):
         with self.transaction():
+            qi = self.quote_identifier
             self.execute(
-                "DELETE FROM {} WHERE pid=:pid".format(self.lock_table_quoted),
+                f"DELETE FROM {self.lock_table_quoted} WHERE {qi('pid')}=:pid",
                 {"pid": pid},
             )
 
     def break_lock(self):
         with self.transaction():
-            self.execute("DELETE FROM {}".format(self.lock_table_quoted))
+            self.execute(f"DELETE FROM {self.lock_table_quoted}")
 
-    def execute(self, sql, params=None):
+    def execute(self, sql, params: t.Union[abc.Mapping[str, t.Any], None] = None):
         """
         Create a new cursor, execute a single statement and return the cursor
         object.
@@ -380,12 +406,9 @@ class DatabaseBackend:
                     (eg 'SELECT * FROM foo WHERE :bar IS NULL')
         :param params: A dictionary of parameters
         """
-        if params and not isinstance(params, Mapping):
-            raise TypeError("Expected dict or other mapping object")
-
         cursor = self.cursor()
-        sql, params = utils.change_param_style(self.driver.paramstyle, sql, params)
-        cursor.execute(sql, params)
+        sql, queryparams = utils.change_param_style(self.driver.paramstyle, sql, params)
+        cursor.execute(sql, queryparams)
         return cursor
 
     def create_lock_table(self):
@@ -394,7 +417,7 @@ class DatabaseBackend:
         """
         try:
             with self.transaction():
-                self.execute(self.create_lock_table_sql.format(self))
+                self.execute(self.format_sql(self.create_lock_table_sql))
         except self.DatabaseError:
             pass
 
@@ -420,7 +443,7 @@ class DatabaseBackend:
         were applied
         """
         self.ensure_internal_schema_updated()
-        sql = self.applied_migrations_sql.format(self)
+        sql = self.format_sql(self.applied_migrations_sql)
         return [row[0] for row in self.execute(sql).fetchall()]
 
     def to_apply(self, migrations):
@@ -524,7 +547,7 @@ class DatabaseBackend:
 
     def unmark_one(self, migration, log=True):
         self.ensure_internal_schema_updated()
-        sql = self.unmark_migration_sql.format(self)
+        sql = self.format_sql(self.unmark_migration_sql)
         self.execute(sql, {"migration_hash": migration.hash})
         if log:
             self.log_migration(migration, "unmark")
@@ -532,23 +555,23 @@ class DatabaseBackend:
     def mark_one(self, migration, log=True):
         self.ensure_internal_schema_updated()
         logger.info("Marking %s applied", migration.id)
-        sql = self.mark_migration_sql.format(self)
+        sql = self.format_sql(self.mark_migration_sql)
         self.execute(
             sql,
             {
                 "migration_hash": migration.hash,
                 "migration_id": migration.id,
-                "when": datetime.utcnow(),
+                "when": datetime.now(timezone.utc).replace(tzinfo=None),
             },
         )
         if log:
             self.log_migration(migration, "mark")
 
-    def log_migration(self, migration, operation, comment=None):
-        sql = self.log_migration_sql.format(self)
-        self.execute(sql, self.get_log_data(migration, operation, comment))
+    def log_migration(self, migration, operation):
+        sql = self.format_sql(self.log_migration_sql)
+        self.execute(sql, self.get_log_data(migration, operation))
 
-    def get_log_data(self, migration=None, operation="apply", comment=None):
+    def get_log_data(self, migration=None, operation="apply"):
         """
         Return a dict of data for insertion into the ``_yoyo_log`` table
         """
@@ -559,9 +582,8 @@ class DatabaseBackend:
             "migration_hash": migration.hash if migration else None,
             "username": getpass.getuser(),
             "hostname": socket.getfqdn(),
-            "created_at_utc": datetime.utcnow(),
+            "created_at_utc": datetime.now(timezone.utc).replace(tzinfo=None),
             "operation": operation,
-            "comment": comment,
         }
 
 
