@@ -3,6 +3,7 @@ Migrate yoyo's internal table structure
 """
 
 from datetime import datetime
+from datetime import timezone
 
 from . import v1
 from . import v2
@@ -48,8 +49,9 @@ def get_current_version(backend):
         return 0
     if version_table not in tables:
         return 1
+    qi = backend.quote_identifier
     cursor = backend.execute(
-        f"SELECT max(version) FROM {backend.quote_identifier(version_table)}"
+        f"SELECT max({qi('version')}) FROM {qi(version_table)}"
     )
     version = cursor.fetchone()[0]
     assert version in schema_versions
@@ -64,6 +66,6 @@ def mark_schema_version(backend, version):
     if version < USE_VERSION_TABLE_FROM:
         return
     backend.execute(
-        "INSERT INTO {0.version_table_quoted} VALUES (:version, :when)".format(backend),
-        {"version": version, "when": datetime.utcnow()},
+        f"INSERT INTO {backend.version_table_quoted} VALUES (:version, :when)",
+        {"version": version, "when": datetime.now(timezone.utc).replace(tzinfo=None)},
     )
