@@ -3,7 +3,6 @@ import pytest
 import yoyo.backends.core
 from yoyo.connections import get_backend
 from yoyo.tests import dburi_sqlite3
-from yoyo.tests import get_test_backends
 from yoyo.tests import get_test_dburis
 
 
@@ -11,20 +10,20 @@ def _backend(dburi):
     """
     Return a backend configured in ``test_databases.ini``
     """
-    backend = get_backend(dburi)
-    with backend.transaction():
-        if backend.__class__ is yoyo.backends.core.MySQLBackend:
-            backend.execute(
-                "CREATE TABLE yoyo_t (id CHAR(1) primary key) ENGINE=InnoDB"
-            )
-        else:
-            backend.execute("CREATE TABLE yoyo_t " "(id CHAR(1) primary key)")
-    try:
-        yield backend
-    finally:
-        backend.rollback()
+    with get_backend(dburi) as backend:
         with backend.transaction():
-            drop_all_tables(backend)
+            if backend.__class__ is yoyo.backends.core.MySQLBackend:
+                backend.execute(
+                    "CREATE TABLE yoyo_t (id CHAR(1) primary key) ENGINE=InnoDB"
+                )
+            else:
+                backend.execute("CREATE TABLE yoyo_t " "(id CHAR(1) primary key)")
+        try:
+            yield backend
+        finally:
+            backend.rollback()
+            with backend.transaction():
+                drop_all_tables(backend)
 
 
 @pytest.fixture(params=get_test_dburis())
@@ -63,5 +62,6 @@ def drop_yoyo_tables(backend):
 
 
 def pytest_configure(config):
-    for backend in get_test_backends():
-        drop_yoyo_tables(backend)
+    for dburi in get_test_dburis():
+        with get_backend(dburi) as backend:
+            drop_yoyo_tables(backend)
