@@ -14,6 +14,7 @@
 
 from shutil import rmtree
 from datetime import datetime
+from datetime import timezone
 from tempfile import mkdtemp
 from functools import partial
 from itertools import count
@@ -32,9 +33,9 @@ import tms
 
 from yoyo import read_migrations
 from yoyo.config import get_configparser
+from yoyo.connections import get_backend
 from yoyo.tests import dburi_sqlite3
 from yoyo.tests import migrations_dir
-from yoyo.tests import get_backend
 from yoyo.scripts.main import main, parse_args, LEGACY_CONFIG_FILENAME
 from yoyo.scripts import newmigration
 
@@ -78,11 +79,10 @@ class TestInteractiveScript(object):
                 cp.write(f)
 
     def get_migration_log(self):
-        return (
-            get_backend(self.dburi)
-            .execute("SELECT migration_id, operation FROM _yoyo_log")
-            .fetchall()
-        )
+        with get_backend(self.dburi) as backend:
+            return backend.execute(
+                "SELECT migration_id, operation FROM _yoyo_log"
+            ).fetchall()
 
 
 class TestYoyoScript(TestInteractiveScript):
@@ -256,15 +256,15 @@ class TestYoyoScript(TestInteractiveScript):
     def test_it_breaks_lock(self, dburi):
         if dburi.startswith("sqlite"):
             pytest.skip("Test not supported for sqlite databases")
-        backend = get_backend(dburi)
-        backend.execute(
-            "INSERT INTO yoyo_lock (locked, ctime, pid) " "VALUES (1, :now, 1)",
-            {"now": datetime.utcnow()},
-        )
-        backend.commit()
-        main(["break-lock", "--database", dburi])
-        lock_count = backend.execute("SELECT COUNT(1) FROM yoyo_lock").fetchone()[0]
-        assert lock_count == 0
+        with get_backend(dburi) as backend:
+            backend.execute(
+                "INSERT INTO yoyo_lock (locked, ctime, pid) " "VALUES (1, :now, 1)",
+                {"now": datetime.now(timezone.utc).replace(tzinfo=None)},
+            )
+            backend.commit()
+            main(["break-lock", "--database", dburi])
+            lock_count = backend.execute("SELECT COUNT(1) FROM yoyo_lock").fetchone()[0]
+            assert lock_count == 0
 
     def test_it_prompts_password_on_break_lock(self):
         dburi = "sqlite://user@/:memory"
@@ -323,14 +323,16 @@ class TestMarkCommand(TestInteractiveScript):
             from yoyo.connections import get_backend
 
             migrations = read_migrations(tmpdir)
-            backend = get_backend(self.dburi)
-            backend.apply_migrations(migrations[:1])
+            with get_backend(self.dburi) as backend:
+                backend.apply_migrations(migrations[:1])
 
-            with patch("yoyo.scripts.migrate.prompt_migrations") as prompt_migrations:
-                main(["mark", tmpdir, "--database", self.dburi])
-                _, prompted, _ = prompt_migrations.call_args[0]
-                prompted = [m.id for m in prompted]
-                assert prompted == ["m2", "m3"]
+                with patch(
+                    "yoyo.scripts.migrate.prompt_migrations"
+                ) as prompt_migrations:
+                    main(["mark", tmpdir, "--database", self.dburi])
+                    _, prompted, _ = prompt_migrations.call_args[0]
+                    prompted = [m.id for m in prompted]
+                    assert prompted == ["m2", "m3"]
 
     def test_it_marks_at_selected_version(self):
         with migrations_dir(
@@ -342,18 +344,18 @@ class TestMarkCommand(TestInteractiveScript):
 
             self.confirm.return_value = True
             migrations = read_migrations(tmpdir)
-            backend = get_backend(self.dburi)
-            with backend.transaction():
-                backend.execute("CREATE TABLE t (id INT)")
+            with get_backend(self.dburi) as backend:
+                with backend.transaction():
+                    backend.execute("CREATE TABLE t (id INT)")
 
-            main(["mark", "-r", "m2", tmpdir, "--database", self.dburi])
-            assert backend.is_applied(migrations[0])
-            assert backend.is_applied(migrations[1])
-            assert not backend.is_applied(migrations[2])
+                main(["mark", "-r", "m2", tmpdir, "--database", self.dburi])
+                assert backend.is_applied(migrations[0])
+                assert backend.is_applied(migrations[1])
+                assert not backend.is_applied(migrations[2])
 
-            # Check that migration steps have not been applied
-            c = backend.execute("SELECT * FROM t")
-            assert len(c.fetchall()) == 0
+                # Check that migration steps have not been applied
+                c = backend.execute("SELECT * FROM t")
+                assert len(c.fetchall()) == 0
 
 
 class TestUnmarkCommand(TestInteractiveScript):
@@ -362,9 +364,9 @@ class TestUnmarkCommand(TestInteractiveScript):
             from yoyo.connections import get_backend
 
             migrations = read_migrations(tmpdir)
-            backend = get_backend(self.dburi)
-            backend.apply_migrations(migrations[:2])
-            assert len(backend.get_applied_migration_hashes()) == 2
+            with get_backend(self.dburi) as backend:
+                backend.apply_migrations(migrations[:2])
+                assert len(backend.get_applied_migration_hashes()) == 2
 
             with patch("yoyo.scripts.migrate.prompt_migrations") as prompt_migrations:
                 main(["unmark", tmpdir, "--database", self.dburi])
@@ -380,13 +382,13 @@ class TestUnmarkCommand(TestInteractiveScript):
 
             self.confirm.return_value = True
             migrations = read_migrations(tmpdir)
-            backend = get_backend(self.dburi)
-            backend.apply_migrations(migrations)
+            with get_backend(self.dburi) as backend:
+                backend.apply_migrations(migrations)
 
-            main(["unmark", "-r", "m2", tmpdir, "--database", self.dburi])
-            assert backend.is_applied(migrations[0])
-            assert not backend.is_applied(migrations[1])
-            assert not backend.is_applied(migrations[2])
+                main(["unmark", "-r", "m2", tmpdir, "--database", self.dburi])
+                assert backend.is_applied(migrations[0])
+                assert not backend.is_applied(migrations[1])
+                assert not backend.is_applied(migrations[2])
 
 
 class TestNewMigration(TestInteractiveScript):
