@@ -14,6 +14,7 @@
 
 from datetime import datetime
 from datetime import timedelta
+from datetime import timezone
 from unittest.mock import Mock, patch
 import io
 import os
@@ -175,12 +176,12 @@ def test_specify_migration_table(tmpdir, dburi):
         step("DROP TABLE yoyo_test")
         """
     ) as tmpdir:
-        backend = get_backend(dburi, migration_table="another_migration_table")
-        migrations = read_migrations(tmpdir)
-        backend.apply_migrations(migrations)
-        cursor = backend.cursor()
-        cursor.execute("SELECT migration_id FROM another_migration_table")
-        assert list(cursor.fetchall()) == [("0",)]
+        with get_backend(dburi, migration_table="another_migration_table") as backend:
+            migrations = read_migrations(tmpdir)
+            backend.apply_migrations(migrations)
+            cursor = backend.cursor()
+            cursor.execute("SELECT migration_id FROM another_migration_table")
+            assert list(cursor.fetchall()) == [("0",)]
 
 
 def test_migration_functions_have_namespace_access(backend_sqlite3):
@@ -315,7 +316,6 @@ class TestAncestorsDescendants(object):
         self.migrations = {self.m1, self.m2, self.m3, self.m4, self.m5}
 
     def test_ancestors(self):
-
         assert ancestors(self.m1, self.migrations) == {
             self.m2,
             self.m3,
@@ -327,7 +327,6 @@ class TestAncestorsDescendants(object):
         assert ancestors(self.m5, self.migrations) == set()
 
     def test_descendants(self):
-
         assert descendants(self.m1, self.migrations) == set()
         assert descendants(self.m2, self.migrations) == {self.m1}
         assert descendants(self.m3, self.migrations) == {self.m2, self.m1}
@@ -456,7 +455,6 @@ class TestReadMigrations(object):
     def test_it_sets_depends_for_sql_migrations(self):
         def check(sql, expected):
             with migrations_dir(**{"1.sql": "", "2.sql": "", "3.sql": sql}) as tmp:
-
                 migration = read_migrations(tmp)[-1]
                 migration.load()
                 assert {m.id for m in migration._depends} == expected
@@ -569,7 +567,9 @@ class TestLogging(object):
             logged = self.get_last_log_entry(backend)
             assert logged["migration_id"] == "a"
             assert logged["operation"] == "apply"
-            assert logged["created_at_utc"] >= datetime.utcnow() - timedelta(seconds=3)
+            assert logged["created_at_utc"] >= (
+                datetime.now(timezone.utc).replace(tzinfo=None) - timedelta(seconds=3)
+            )
             apply_time = logged["created_at_utc"]
 
             backend.rollback_migrations(migrations)
@@ -587,7 +587,9 @@ class TestLogging(object):
             logged = self.get_last_log_entry(backend)
             assert logged["migration_id"] == "a"
             assert logged["operation"] == "mark"
-            assert logged["created_at_utc"] >= datetime.utcnow() - timedelta(seconds=3)
+            assert logged["created_at_utc"] >= (
+                datetime.now(timezone.utc).replace(tzinfo=None) - timedelta(seconds=3)
+            )
             marked_time = logged["created_at_utc"]
 
             backend.unmark_migrations(migrations)
