@@ -13,6 +13,7 @@
 # limitations under the License.
 
 from itertools import count
+from collections import abc
 import configparser
 import os
 import random
@@ -20,6 +21,7 @@ import re
 import string
 import sys
 import unicodedata
+import typing as t
 
 from yoyo.config import CONFIG_EDITOR_KEY
 
@@ -125,18 +127,22 @@ def get_random_string(length, chars=(string.ascii_letters + string.digits)):
     return "".join(rng.choice(chars) for i in range(length))
 
 
-def change_param_style(target_style, sql, bind_parameters):
+def change_param_style(
+    target_style: str,
+    sql: str,
+    bind_parameters: t.Optional[abc.Mapping[str, t.Any]]
+) -> tuple[str, t.Union[abc.Mapping[str, t.Any], abc.Sequence[str]]]:
     """
     :param target_style: A DBAPI paramstyle value (eg 'qmark', 'format', etc)
     :param sql: An SQL str
-    :bind_parameters: A dict of bind parameters for the query
+    :param bind_parameters: A dict of bind parameters for the query
 
     :return: tuple of `(sql, bind_parameters)`. ``sql`` will be rewritten with
              the target paramstyle; ``bind_parameters`` will be a tuple or
              dict as required.
     """
     if target_style == "named":
-        return sql, bind_parameters
+        return sql, bind_parameters or {}
     positional = target_style in {"qmark", "numeric", "format"}
     if not bind_parameters:
         return (sql, (tuple() if positional else {}))
